; A statement ends with a semicolon, characters on a line after the semicolon are ignored
; lines starting with a semicolon are treated as comments

create table configuration (
    MAINFRAMEWIDTH	INT,
    MAINFRAMEHEIGHT	INT,
	USECLIPBOARD	BOOLEAN
);

create table account (
    ID          BIGINT NOT NULL PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    NAME        VARCHAR(50) UNIQUE,
	ISDEFAULT	BOOLEAN,
	SEQUENCE	INT,
	LANGUAGE	VARCHAR(20),
	VERSION		VARCHAR(20)
);

create table war (
    ID          BIGINT NOT NULL PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    ACCOUNT     BIGINT NOT NULL,
    NAME        VARCHAR(255),
	STARTDATE	BIGINT NOT NULL,
	ENDDATE		BIGINT,
	WINNER		VARCHAR(10),
    FOREIGN KEY(ACCOUNT) REFERENCES account(ID) ON DELETE CASCADE
);

create unique index warIndex on war (ACCOUNT, NAME);

create table party (
    ID          BIGINT NOT NULL PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
	WAR			BIGINT,
	NAME		VARCHAR(255),
	SIDE		VARCHAR(10),
	KILLEDUNITS	BIGINT,
	LOWERCOLOR	INT NOT NULL,
	UPPERCOLOR	INT NOT NULL,
	IRON		BIGINT,
	METAL		BIGINT,
	KRYPTONITE	BIGINT,
	SPICE		BIGINT,
	TF_IRON			BIGINT,
	TF_METAL		BIGINT,
	TF_KRYPTONITE	BIGINT,
	TF_SPICE		BIGINT,
    FOREIGN KEY(WAR) REFERENCES war(ID) ON DELETE CASCADE
);

create unique index partyIndex on party (WAR, SIDE);

create table player (
    ID          BIGINT NOT NULL PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    PARTY	    BIGINT NOT NULL,
    NAME        VARCHAR(255),
    ALLIANCE    VARCHAR(255),
    FOREIGN KEY(PARTY) REFERENCES party(ID) ON DELETE CASCADE
);

create unique index playerIndex on player (PARTY, NAME);

create table battlereport (
    ID          BIGINT NOT NULL PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    ACCOUNT     BIGINT  NOT NULL,
	LANGUAGE	VARCHAR(20),
    CREATETIME  BIGINT NOT NULL,
    POSITION    INT NOT NULL,
    ATTACKER    BIGINT  NOT NULL,
    DEFENDER    BIGINT  NOT NULL,
    ATTACKERNAMES   VARCHAR(32670),
    DEFENDERNAME    VARCHAR(255),
    ATTACKERKILLEDUNITS    BIGINT,
    DEFENDERKILLEDUNITS    BIGINT,
	IRON		BIGINT,
	METAL		BIGINT,
	KRYPTONITE	BIGINT,
	SPICE		BIGINT,
	REPORTDATA	VARCHAR(32670),
    FOREIGN KEY(ACCOUNT) REFERENCES account(ID) ON DELETE CASCADE,
    FOREIGN KEY(ATTACKER) REFERENCES party(ID) ON DELETE CASCADE,
    FOREIGN KEY(DEFENDER) REFERENCES party(ID) ON DELETE CASCADE
);

create index battlereportIndex on battlereport (POSITION, ACCOUNT, CREATETIME);

create table recyclingreport (
    ID          BIGINT NOT NULL PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    ACCOUNT     BIGINT  NOT NULL,
    CREATETIME  BIGINT NOT NULL,
    POSITION    INT NOT NULL,
    PARTY       BIGINT  NOT NULL,
	IRON		BIGINT,
	METAL		BIGINT,
	KRYPTONITE	BIGINT,
	SPICE		BIGINT,
	REPORTDATA	VARCHAR(32670),
    FOREIGN KEY(ACCOUNT) REFERENCES account(ID) ON DELETE CASCADE,
    FOREIGN KEY(PARTY) REFERENCES party(ID) ON DELETE CASCADE
);

create index recyclingreportIndex on recyclingreport (POSITION, ACCOUNT, CREATETIME);
